@@ -46,18 +46,8 @@ class Message::Entity
     @@linkrule = {}
     @@filter = Hash.new(filter_wrap(&ret_nth))
     filter(:urls){ |segment|
-      segment[:face] ||= segment[:url]
-      if UserConfig[:shrinkurl_expand]
-        url = segment[:expanded_url] || segment[:url]
-        if MessageConverters.shrinked_url? url
-          segment[:face] = MessageConverters.expand_url([url])[url]
-        elsif segment[:expanded_url]
-          begin
-            normalized = Addressable::URI.parse('//'+segment[:display_url]).display_uri.to_s
-            segment[:face] = normalized[2, normalized.size]
-          rescue => e
-            error e
-            segment[:face] = segment[:display_url] end end end
+      segment[:face] = (segment[:display_url] or segment[:url])
+      segment[:url] = (segment[:expanded_url] or segment[:url])
       segment }
 
     filter(:media){ |segment|
@@ -79,15 +69,7 @@ class Message::Entity
   def initialize(message)
     type_strict message => Message
     @message = message
-    @generate_thread = Thread.new {
-      begin
-        @generate_value = _generate_value || []
-      rescue TimeoutError => e
-        error "entity parse timeout. ##{message[:id]}(@#{message.user[:idname]}: #{message.to_show})"
-        raise RuntimeError, "entity parse timeout. ##{message[:id]}(@#{message.user[:idname]}: #{message.to_show})"
-      rescue Exception => e
-        error e end
-      @generate_thread = nil } end
+    @generate_value = _generate_value || [] end
 
   def each
     to_a.each(&Proc.new)
@@ -112,6 +94,28 @@ class Message::Entity
       else
         s end }.join end
 
+  # 外部からエンティティを書き換える。
+  # これでエンティティが書き換えられた場合、イベントで書き換えが通知される。
+  # また、エンティティの範囲が被った場合それを削除する
+  # ==== Args
+  # [addition] Hash 以下の要素を持つ配列
+  #   - :slug (required) :: Symbol エンティティの種類。:urls 等
+  #   - :url (required) :: String 実際のクエリ(リンク先URL等)
+  #   - :face (required) :: String 表示する文字列
+  #   - :range (required) :: Range message上の置き換える範囲
+  #   - :message :: Message 親Message
+  # ==== Return
+  # self
+  def add(addition)
+    type_strict addition[:slug] => Symbol, addition[:url] => String, addition[:face] => String, addition[:range] => Range
+    links = select{|link|
+      (link[:range].to_a & addition[:range].to_a).empty?
+    }
+    links.push @@linkrule[addition[:slug]].merge(addition)
+    @generate_value = links.sort_by{ |r| r[:range].first }.freeze
+    Plugin.call(:message_modified, message)
+  end
+
   # _index_ 文字目のエンティティの要素を返す。エンティティでなければnilを返す
   def segment_by_index(index)
     segment_text.each{ |segment|
@@ -149,7 +153,6 @@ class Message::Entity
     result.freeze end
 
   def generate_value
-    @generate_thread.join if @generate_thread
     @generate_value end
 
   def _generate_value
@@ -177,12 +180,22 @@ class Message::Entity
         children.each{ |link|
           begin
             rule = @@linkrule[slug] || {}
-            entity = @@filter[slug].call(rule.merge({ :message => message,
-                                                      :from => :message_entities}.merge(link)))
-            entity[:range] = get_range_by_face(entity) #indices_to_range(link[:indices])
-            result << entity.freeze
+            extended_entities = matched_extended_entites(slug, link[:display_url])
+            if extended_entities.empty?
+              entity = @@filter[slug].call(rule.merge({ message: message,
+                                                        from: :message_entities
+                                                      }.merge(link)))
+              entity[:range] = get_range_by_face(entity)
+              result << entity.freeze
+            else
+              entities_from_extended_entities(link, extended_entities, message: message, slug: slug, rule: rule).each do |converted_entity|
+                converted_entity[:range] = get_range_by_face(converted_entity)
+                result << converted_entity.freeze end
+            end
           rescue InvalidEntityError, RuntimeError => exception
-            error exception end } } end
+            error exception end } }
+
+    end
     result.sort_by{ |r| r[:range].first }.freeze end
 
   def get_range_by_face(link)
@@ -201,6 +214,43 @@ class Message::Entity
     Range.new(self.class.index_to_escaped_index(message.to_show, indices[0]),
               self.class.index_to_escaped_index(message.to_show, indices[1]), true) end
 
+  # source_entity に対する extended_entity を、通常のエンティティに変換して返す。
+  # source_entity のテキスト上の表現の1文字にextended_entityの1つを割り当て、最後のextended_entity
+  # には残りの全てを割り当てる。
+  # ==== Args
+  # [source_entity] Hash 元となるエンティティ
+  # [extended_entities] Array Extended Entity
+  # ==== Return
+  # entityの配列
+  def entities_from_extended_entities(source_entity, extended_entities, slug: source_entity[:slug], rule: @@linkrule[slug] || {}, message: nil)
+    type_strict source_entity => Hash, extended_entities => Array, slug => Symbol, rule => Hash, message => Message
+    result = extended_entities.map.with_index do |extended_entity, index|
+                entity_rewrite = {
+                  display_url: extended_entity[:media_url],
+                  indices: [source_entity[:indices][0]+index, source_entity[:indices][0]+index+1] }
+                if 0 != index
+                  entity_rewrite[:display_url] = "\n#{entity_rewrite[:display_url]}" end
+                @@filter[slug].call(rule.merge({ message: message,
+                                                 from: :message_entities
+                                               }.merge(extended_entity).
+                                                merge(entity_rewrite))) end
+    result.last[:indices][1] = source_entity[:indices][1]
+    result end
+
+  # slug と　display_url が一致するextended entitiesを返す
+  # ==== Args
+  # [slug] Symbol Entityのスラッグ
+  # [display_url] String 探すExtended Entityのdisplay_url
+  # ==== Return
+  # Extended Entityの配列。見つからなかった場合は空の配列
+  def matched_extended_entites(slug, display_url)
+    if defined?(message[:extended_entities][slug]) and message[:extended_entities][slug].is_a? Array
+      message[:extended_entities][slug].select do |link|
+        display_url == link[:display_url] end
+    else
+    [] end end
+
+
   # to_showで得たエンティティデコードされた文字列の index が、
   # エンティティエンコードされた文字列ではどうなるかを返す。
   # ==== Args
@@ -214,14 +264,6 @@ class Message::Entity
       .slice(0, encoded_index)
       .gsub(REGEXP_ENTITY_DECODE_TARGET, &UNESCAPE_RULE.method(:[]))
       .size end
-    # decoded_string
-    #   .split(REGEXP_EACH_CHARACTER)
-    #   .map{ |s| ESCAPE_RULE[s] || s }
-    #   .join
-    #   .split(REGEXP_EACH_CHARACTER)[0, encoded_index]
-    #   .join
-    #   .gsub(/&.+?;/, '.'.freeze)
-    #   .size end
 
   class InvalidEntityError < Message::MessageError
   end
