@@ -5,6 +5,8 @@ require "mikutwitter/query"
 require "json"
 require "timelimitedqueue"
 
+miquire :core, "message", "user", "userlist"
+
 module MikuTwitter::ApiCallSupport
   HTML_ATTR_UNESCAPE_HASH = {
     '&amp;' => '&',
@@ -110,6 +112,9 @@ module MikuTwitter::ApiCallSupport
         cnv[:retweet] = message(msg[:retweeted_status]) if msg[:retweeted_status]
         cnv[:exact] = [:created_at, :source, :user, :retweeted_status].all?{|k|msg.has_key?(k)}
         message = cnv[:exact] ? Message.rewind(cnv) : Message.new_ifnecessary(cnv)
+        # search/tweets.json の戻り値のquoted_statusのuserがたまにnullだゾ〜
+        if msg[:quoted_status].is_a?(Hash) and msg[:quoted_status][:user]
+          message(msg[:quoted_status]).add_quoted_by(message) end
         message end
 
       def messages(msgs)
