@@ -26,7 +26,11 @@ module Gdk::IconOverButton
   def globalpos2iconpos(gx, gy)
     lx, ly = gx - pos.main_icon.x, gy - pos.main_icon.y
     w, h = pos.main_icon.width / _schemer[:x_count], pos.main_icon.height / _schemer[:y_count]
-    [(lx / w).to_i, (ly / h).to_i] end
+    ipx, ipy = (lx / w).to_i, (ly / h).to_i
+    if ipx >= 0 and ipx < _schemer[:x_count] and ipy >= 0 and ipy < _schemer[:y_count]
+      [ipx, ipy]
+    else
+      nil end end
 
   # _context_ にicon over buttonを描画する。
   def render_icon_over_button(context)
@@ -61,30 +65,29 @@ module Gdk::IconOverButton
   # - _gx_ MiraclePainter全体から見たx座標
   # - _gy_MiraclePainter 全体から見たy座標
   def point_moved_main_icon(gx, gy)
-    ipx, ipy = ip = globalpos2iconpos(gx, gy)
-    if ipx >= 0 and ipx < _schemer[:x_count] and ipy >= 0 and ipy < _schemer[:y_count]
-      if current_icon_pos != ip
+    icon_position = globalpos2iconpos(gx, gy)
+    if icon_position
+      if current_icon_pos != icon_position
         on_modify
-        @current_icon_pos = ip end
+        @current_icon_pos = icon_position end
     else
-      iob_main_leave
-    end
-  end
+      iob_main_leave end end
 
   # icon over buttonからマウスポインタが離れたときに呼ぶ。
   def iob_main_leave
     if(current_icon_pos)
       @current_icon_pos = nil
-      on_modify
-    end
-  end
+      on_modify end end
 
-  # icon over buttonがクリックされたことを通知する。
-  # 最後に point_moved_main_icon() が呼ばれた箇所がクリックされたことになる
-  def iob_clicked
+  # icon over buttonがクリックされたことを通知する
+  # ==== Args
+  # [gx] MiraclePainter全体から見たx座標
+  # [gy] MiraclePainter全体から見たy座標
+  def iob_clicked(gx, gy)
+    icon_position = globalpos2iconpos(gx, gy)
     return if message.to_message.system?
-    if(current_icon_pos)
+    if icon_position
       __send__([ [:iob_reply_clicked, :iob_etc_clicked],
-                 [:iob_retweet_clicked, :iob_fav_clicked]][current_icon_pos[0]][current_icon_pos[1]]) end end
+                 [:iob_retweet_clicked, :iob_fav_clicked]][icon_position[0]][icon_position[1]]) end end
 
 end
