@@ -84,19 +84,17 @@ class Gtk::TimeLine
   def block_add_all(messages)
     removes, appends = *messages.partition{ |m| m[:rule] == :destroy }
     remove_if_exists_all(removes)
-    retweets, appends = *messages.partition{ |m| m[:retweet] }
+    retweets, appends = *appends.partition{ |m| m[:retweet] }
     add_retweets(retweets)
     appends.sort_by{ |m| -get_order(m) }.deach(&method(:block_add))
   end
 
   # リツイートを追加する。 _messages_ には Message の配列を指定し、それらはretweetでなければならない
   def add_retweets(messages)
-    messages.each{ |message|
-      if not include?(message.retweet_source)
-        block_add(message.retweet_source)
-      end
-    }
-  end
+    messages.reject{|message|
+      include?(message.retweet_source)
+    }.deach do |message|
+      block_add(message.retweet_source) end end
 
   # Messageオブジェクト _message_ が更新されたときに呼ばれる
   def modified(message)
