@@ -79,7 +79,6 @@ Plugin.create :change_account do
   def jump_seq(name)
     if defined? @sequence[name]
       store(:tutorial_sequence, name)
-      notice "sequence move to #{name}"
       if @sequence.has_key? name
         @sequence[name].call
       else
@@ -88,12 +87,10 @@ Plugin.create :change_account do
 
   def request_token(reset = false)
     if !@request_token || reset
-      @request_token = parallel {
-        twitter = MikuTwitter.new
-        twitter.consumer_key = Environment::TWITTER_CONSUMER_KEY
-        twitter.consumer_secret = Environment::TWITTER_CONSUMER_SECRET
-        twitter.request_oauth_token } end
-
+      twitter = MikuTwitter.new
+      twitter.consumer_key = Environment::TWITTER_CONSUMER_KEY
+      twitter.consumer_secret = Environment::TWITTER_CONSUMER_SECRET
+      @request_token = twitter.request_oauth_token end
     @request_token end
 
   defsequence :first do
