@@ -57,12 +57,12 @@ Plugin.create :photo_support do
   end
 
   # gyazo
-  defimageopener('gyazo', %r<^http://gyazo.com/[a-zA-Z0-9]+>) do |display_url|
+  defimageopener('gyazo', %r<\Ahttps?://gyazo.com/[a-zA-Z0-9]+>) do |display_url|
     connection = HTTPClient.new
     page = connection.get_content(display_url)
     next nil if page.empty?
     doc = Nokogiri::HTML(page)
-    result = doc.css('#gyazo_img').first
+    result = doc.css('.image').first
     open(result.attribute('src'))
   end
 
