@@ -26,6 +26,7 @@ class User < Retriever::Model
                [:profile_image_url, :string],
                [:url, :string],
                [:protected, :bool],
+               [:verified, :bool],
                [:followers_count, :int],
                [:statuses_count, :int],
                [:friends_count, :int],
@@ -59,6 +60,14 @@ class User < Retriever::Model
     self[:idname] end
   alias to_s idname
 
+  def protected?
+    !!self[:protected]
+  end
+
+  def verified?
+    !!self[:verified]
+  end
+
   # 大きいサイズのアイコンのURLを返す
   # ==== Return
   # 元のサイズのアイコンのURL
@@ -126,6 +135,10 @@ class User < Retriever::Model
   def count_favorite_given
     @value[:favourites_count] end
 
+  def user
+    self end
+  alias to_user user
+
   def marshal_dump
     raise RuntimeError, 'User cannot marshalize'
   end
