@@ -9,13 +9,12 @@ if defined? HYDE
   require File.expand_path(File.join(File.dirname(__FILE__), 'utils'))
 end
 
-require 'yaml'
 require 'thread'
-require 'pstore'
 require 'monitor'
 require "open-uri"
 
 $atomic = Monitor.new
+$log_lock = Mutex.new
 
 # 基本的な単位であり、数学的にも重要なマジックナンバーで、至るところで使われる。
 # これが言語仕様に含まれていないRubyは正直気が狂っていると思う。
@@ -36,8 +35,8 @@ require File.join(File::dirname(__FILE__), 'miquire')
 miquire :lib, 'lazy'
 
 # すべてのクラスにメモ化機能を
-miquire :lib, 'memoize'
-include Memoize
+miquire :lib, 'memoist'
+include Memoist
 
 # Environment::CONFROOT内のファイル名を得る。
 #   confroot(*path)
@@ -66,14 +65,14 @@ def gen_counter(count=0, increment=1)
 
 # ファイルの内容を文字列に読み込む
 def file_get_contents(fn)
-  open(fn, 'r:utf-8'){ |input|
+  open(fn, 'rb:utf-8'.freeze){ |input|
     input.read
   }
 end
 
 # 文字列をファイルに書き込む
 def file_put_contents(fn, body)
-  File.open(fn, 'w'){ |put|
+  File.open(fn, 'wb'.freeze){ |put|
     put.write body
     body
   }
@@ -82,7 +81,7 @@ end
 # ファイル _fn_ の内容からオブジェクトを読み込む。
 # _fn_ は、object_put_contents() で保存されたファイルでなければならない。
 def object_get_contents(fn)
-  File.open(fn, 'r'){ |input|
+  File.open(fn, 'rb'.freeze){ |input|
     Marshal.load input
   }
 end
@@ -99,7 +98,7 @@ def require_if_exist(file)
     require file
     true
   rescue LoadError
-    notice "require-if-exist: file not found: #{file}"
+    warn "require-if-exist: file not found: #{file}"
     false end end
 
 # _insertion_ を、 _src_ の挿入するべき場所のインデックスを返す。
@@ -236,11 +235,12 @@ def log(prefix, object)
     msg = "#{prefix}: #{caller_util}: #{object}"
     msg += "\nfrom " + object.backtrace.join("\nfrom ") if object.is_a? Exception
     unless $daemon
-      if msg.is_a? Exception
-        __write_stderr(msg.to_s)
-        __write_stderr(msg.backtrace.join("\n"))
-      else
-        __write_stderr(msg) end
+      $log_lock.synchronize do
+        if msg.is_a? Exception
+          __write_stderr(msg.to_s)
+          __write_stderr(msg.backtrace.join("\n"))
+        else
+          __write_stderr(msg) end end
       if logfile
         FileUtils.mkdir_p(File.expand_path(File.dirname(logfile + '_')))
         File.open(File.expand_path("#{logfile}#{Time.now.strftime('%Y-%m-%d')}.log"), 'a'){ |wp|
@@ -250,7 +250,7 @@ def log(prefix, object)
   end
 end
 
-FOLLOW_DIR = File.expand_path('..')
+FOLLOW_DIR = File.expand_path(File.join(File.dirname(__FILE__), '..'))
 def __write_stderr (msg)
   $stderr.write(msg.gsub(FOLLOW_DIR, '{MIKUTTER_DIR}')+"\n")
 end
@@ -393,6 +393,7 @@ class String
       match(str) end end
 
   def matches(regexp)
+    warn "String#matches is obsolete method. use String#scan"
     result = []
     each_matches(regexp){ |m, pos|
       result << m.to_s }
@@ -400,6 +401,7 @@ class String
   end
 
   def each_matches(regexp, &proc) # :yield: match, byte_index, char_intex
+    warn "String#each_matches is obsolete method. use String#scan"
     pos = 0
     str = self
     while(match = regexp.match(str))
@@ -455,22 +457,3 @@ class Regexp
     new(o['data'])
   end
 end
-
-class HatsuneStore < PStore
-
-  def initialize(*args)
-    extend MonitorMixin
-    super
-  end
-
-  def transaction(ro = false, &block)
-    start = Time.now
-    result = synchronize{
-      super(ro){ |db| block.call(db) } }
-    if (Time.now - start) >= 0.1
-      notice "%.4f" % (Time.now - start)
-    end
-    result
-  end
-end
-
